<template>
  <el-dialog
    width="60%"
    title="工艺工序参数集"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="part-dialog"
  >
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :ajaxFun="ajaxFun"
      :paramObj="paramTemplateObj"
      :selColValArr="paramTemplateSelArr"
      :selCol="paramTemplateSelCol"
      :bottomOffset="350"
      ref="operationParamTemplateTable"
    >
      <template #toolbar></template>
    </ttable>
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import { getRoutingOperationTemplatePage } from '@/api/technology/routing'
import ttable from '@/views/common/ztt-table.vue'
import { mapGetters } from 'vuex'
export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    multiSelect: {
      type: Boolean,
      default: true
    },
    paramTemplateObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    // 默认选中字段的值数组
    paramTemplateSelArr: {
      type: Array,
      default: () => {
        return []
      }
    },
    // 默认选中字段
    paramTemplateSelCol: {
      type: String
    }
  },
  data() {
    return {
      ajaxFun: getRoutingOperationTemplatePage,
      currentRow: null,
      innerVisible: false,
      multipleSelection: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operationParamTemplate',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: true, // 高级查询按钮
        defaultOrderBy: { column: 'operationTemplateName', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: 'code',
            prop: 'operationTemplateName',
            label: '模板名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'operationTemplateNo',
            label: '模板编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'operationTemplateType',
            label: '类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ]
      }
    }
  },
  components: {
    ttable
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    }
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  created() {},
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.operationParamTemplateTable.getDataList()
    },
    saveSelectRow() {
      if (this.multiSelect) {
        this.$emit('handleSelectionParamTemplateChange', this.multipleSelection)
      } else {
        this.$emit('listenToParamTemplateEvent', this.currentRow)
      }
      this.innerVisible = false
    },
    handleCurrentChange(row) {
      this.currentRow = row
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    }
  }
}
</script>
